<?php
/*
Send sales enquiry
ecode returns:
	fatal - setup incorrect
	nosite - no site passed
	badsite - no site exists with the ID passed
	nosales - no sales email could be found
	noemail - email sending failed
*/

// JavaScript header
header('Content-type: text/javascript');

// set application defaults
$defaults='INCLUDEFOLDER;IMAGEFOLDER;DATAFOLDER;';

$ini=parse_ini_file('./autodirector.ini');
foreach ($ini as $key=>$value) {
	define($key, $value);
	$defaults=str_replace($key.';', '', $defaults);
}
unset($ini);

// missing application defaults
$ecode = "";
$ewarn = "";
if ($defaults!='') $ecode = "fatal";
unset($defaults);

// ________________________________________________________
// MAIN APPLICATION

// passed parameters
$site = '';
$id = '';
$callback = '';
if ($ecode == "") {
	$site = getvar('site');	if ($site == "") $ecode = 'nosite';
	$id = getvar('id'); if ($id == "" || !is_numeric($id)) { $id = ""; $ewarn = "No vehicle ID was passed.\n"; }
	$callback = getvar('callback');
	$url = getvar('url'); if ($url != "") $url = 'http://' . $url; else $ewarn .= "No URL was passed.\n";
	$name = getvar('name'); if ($name == "") $ewarn .= "No name was passed.\n";
	$email = getvar('email');
	if ($email != '' && (preg_match('/^.+@[a-z0-9]+([_\.\-]{0,1}[a-z0-9]+)*([\.]{1}[a-z0-9]+)+$/', $email) != 1 || strpos($email, '\r') !== false || strpos($email, '\n') !== false)) {
		$ewarn .= "Possible spam attempt: email=$email\n";
		$email = '';
	}
	$tel = getvar('tel');
	if ($email == '' && $tel == '') $ewarn .= "No email address or telephone number was passed.\n";
	$comments = str_replace("\r\n", "\n", getvar('comments'));
	$oldc = '';
	while ($oldc != $comments) {
		$oldc = $comments;
		$comments = str_replace("\n\n", "\n", $comments);
	}
}

// fetch sales email
$salesemail='';
if ($ecode == "") {

	// database handler
	require(INCLUDEFOLDER.'dbhandler.php');
	$db=new dbObject;
	$db->pagesize=0;

	if ($db->fetch("SELECT emailsales FROM sites WHERE siteid='$site';")) {
		if ($db->rowcount==1) {
			$row=$db->row();
			$salesemail=$row[0];
		}
		else $ecode.='badsite';
	}
	else $ewarn.="A database problem occurred when fetching the sales email.\n";
}

// find vehicle information
$carinfo = false;
if ($ecode == "" && $id != "") {
	if ($db->fetch("SELECT new,year,make,model,type,regnumber,colour,gearbox,price,views,enquiries FROM $site WHERE id=$id;")) {
		if ($db->rowcount==1) {
			$car=$db->rowassoc();
			if ($car['new']) $carname="New"; else $carname=$car['year'];
			$carname.=" ${car['make']} ${car['model']} ${car['type']}";
			$carreg=$car['regnumber'];
			$carcolour=$car['colour'];
			$cargearbox=$car['gearbox'];
			$carprice=$car['price'];
			$carviews=$car['views'];
			$carenqs=$car['enquiries']+1;
			$db->fetch("UPDATE $site SET enquiries=$carenqs WHERE id=$id;");
			$carinfo = true;
		}
		else $ewarn.="The vehicle with ID $id could not be found.\n";
	}
	else $ewarn.="A database problem occurred when fetching car details.\n";
}

// disconnect from database
if (isset($db)) {
	$db->dbDisconnect();
	unset($db);
}

// email setup
if ($ecode == "") {
	if ($email=='') $header="From: $salesemail\n"; else $header="From: $name <$email>\n";
	$subject='sales enquiry'.($carinfo ? ": $carname" : '');
	$body=gmdate("l, j F Y, H:i")."\n\n";
	if ($name!='') $body.="name: $name\n";
	if ($email!='') $body.="email: <$email>\n";
	if ($tel!='') $body.="telephone: $tel\n";
	if ($comments!='') $body.="comments:\n$comments\n";

	if ($carinfo) {
		$body.="\nVEHICLE DETAILS:\n\t$carname\n";
		if ($carreg!='') $body.="\t$carreg\n";
		if ($carcolour!='') $body.="\t$carcolour\n";
		if ($cargearbox!='unknown') $body.="\t$cargearbox\n";
		if (is_numeric($carprice)) $body.="\tprice: ".number_format($carprice)."\n";

		$body.="\tThis vehicle has been viewed $carviews time";
		if ($carviews!=1) $body.='s';
		$body.="\n\tand this is enquiry $carenqs";
		$body.="\n\n\tID:  $id\n";
	}
	else if ($id != '') $body.="\nA vehicle ID of $id was passed, but it does not exist in the database.\n\n";
	if ($url != '' && $carinfo) $body.="\tURL: <$url?cid=$id>\n";
	
	// send email
	if ($salesemail != '') {
		$b = $body;
		if (defined('ADVERT')) $b .= "\n\n".ADVERT.(defined('ADVERTURL') ? ' - '.ADVERTURL : '');
		if (defined('SUPPORTEMAIL')) $b .= "\nSupport: ".SUPPORTEMAIL;
		$b .= "\n\nPowered by AutoDirector - http://www.autodirector.co.uk/";
		if (!@mail($salesemail, $subject, $b, $header)) $ecode='noemail';
	}
	else $ecode='nosales';
}

// log enquiry
if ($ecode != 'fatal' && $ecode != 'nosite' && $ecode != 'badsite') {

	$enqlog=DATAFOLDER.$site."/enquiries.txt";
	$res = 'NEW ENQUIRY: '.gmdate("l j F Y, H:i")." GMT\n";

	switch($ecode) {
		case 'nosales': $res.="No sales email address is available: the following enquiry could NOT be sent:"; break;
		case 'noemail': $res.="The following enquiry to $salesemail could NOT be sent (mail failure):"; break;
		default: $res.="The following enquiry was successfully sent to $salesemail:";
	}
	$res.="\n".str_repeat('-', 40)."\n\n$subject\n\n$body\n\n";
	if ($ewarn != '') $res.="The following warnings were generated:\n$ewarn\n";
	$res.=str_repeat('_', 60)."\n\n";

	if ($fp=@fopen($enqlog, 'a')) {
		fwrite($fp, $res);
		fclose($fp);
	}
}

// return JavaScript
print "setup.senderror='$ecode';\n";
if ($ecode != '' && $salesemail !='') print "setup.salesemail='$salesemail';\n";
print "$callback;\n";


// ________________________________________________________
// fetches a GET form variable or sets to a default
function getvar($var, $default="") {
	if (isset($_GET[$var])) {
		$ret=$_GET[$var];
		if (get_magic_quotes_gpc()) $ret=stripslashes($ret);
	}
	else {
		$ret=$default;
	}
	return $ret;
}
?>
